/************************************************************
   Copyright (C) 1993 by The Trustees of Columbia University in the City 
   of New York

   OBJECT-ORIENTED Protein Data Bank Project
   Biochemistry and Molecular Biophysics, Computer Science depts.
 **************************************************************

   File: oopdb_setup.h
   Responsable: Weider Chang, Ph.D



  This header file setup proper enviroment to be included during
  compiling.

***************************************************************/
#ifndef _H_SETUP
#define _H_SETUP

#ifdef MOTIF
#define Atom ATOM
#endif

#define NEED_CALC 1   /* change to 0 to exclude calc object and methods
			 that use calc object. */
#ifndef NO_OS

#define NEED_OBJECTSTORE 1 /* change to 0 to exclude objectstore definition.
			      Also, you need to modify the makefile to proper
			      setting. */
#endif

#ifdef NO_OS /* you also can define this in your makefile to exclude OS */

#define NEED_OBJECTSTORE 0  

#endif
#endif
