/************************************************************
   Copyright (C) 1993 by The Trustees of Columbia University in the City 
   of New York

   OBJECT-ORIENTED Protein Data Bank Project
   Biochemistry and Molecular Biophysics, Computer Science depts.
 **************************************************************

   File: os_structure.h
   Responsable: Weider Chang, Ph.D

 **************************************************************/

#include "oopdb_setup.h"
#include "structure.h"

class OSAtom : public Atom {
};

class OSSecondaryStruc : Public SecondaryStruc {
};

class 
