/************************************************************
   Copyright (C) 1993 by The Trustees of Columbia University in the City 
   of New York

   OBJECT-ORIENTED Protein Data Bank Project
   Biochemistry and Molecular Biophysics, Computer Science depts.
 **************************************************************

   File: os_pdb.h
   Responsable: Weider Chang, Ph.D

 **************************************************************/

#include <ostore/ostore.hh>
#include "oopdb_setup.h"

class OSPDB {
 public:
  OSPDB();
  OSPDB(char * db_file_name);
  ~OSPDB();
  os_database *db;
};
