/************************************************************
   Copyright (C) 1993 by The Trustees of Columbia University in the City 
   of New York

   OBJECT-ORIENTED Protein Data Bank Project
   Biochemistry and Molecular Biophysics, Computer Science depts.
 **************************************************************

   File: pdbfile.h
   Responsable: Weider Chang, Ph.D

 **************************************************************/

#ifndef _H_PDBFILE
#define _H_PDBFILE

#include "oopdb_setup.h"
#include "i_pdbfile.h"

class PdbFile : public IntrPdbFile {
 public:
  PdbFile() {};
  PdbFile(char* filename) : IntrPdbFile(filename) {}
};

class PdbInfoIter  : public IntrPdbInfoIter {
 public:
  PdbInfoIter();
  PdbInfoIter(LineBuffer * line_p) : IntrPdbInfoIter(line_p) {}
};

#endif







