/************************************************************
   Copyright (C) 1993 by The Trustees of Columbia University in the City 
   of New York

   OBJECT-ORIENTED Protein Data Bank Project
   Biochemistry and Molecular Biophysics, Computer Science depts.
 **************************************************************

   File: linebuffer.h
   Responsable: Weider Chang, Ph.D

 **************************************************************/
#ifndef _H_LINEBUFFER
#define _H_LINEBUFFER

#include <stdio.h>
#include <iostream.h>
#include <string.h>

class LineBuffer;

class IntrLineBuffer {
public:
	LineBuffer * d_next_p;
	char d_buf[82];
	IntrLineBuffer();
	char * print();
friend ostream& operator<<(ostream& o, LineBuffer* line_p);
};

class LineBuffer : public IntrLineBuffer {
};

#endif
