/************************************************************
   Copyright (C) 1993 by The Trustees of Columbia University in the City 
   of New York

   OBJECT-ORIENTED Protein Data Bank Project
   Biochemistry and Molecular Biophysics, Computer Science depts.
 **************************************************************

   File: subentity.h
   Responsable: Weider Chang, Ph.D

 **************************************************************/

#ifndef _H_SUBENTITY
#define _H_SUBENTITY

#include "oopdb_setup.h"
#include "i_subentity.h"

class SubEntity : public IntrSubEntity{
 public:
  SubEntity(char* name) : IntrSubEntity(name){}
};

#endif
