/************************************************************
   Copyright (C) 1993 by The Trustees of Columbia University in the City 
   of New York

   OBJECT-ORIENTED Protein Data Bank Project
   Biochemistry and Molecular Biophysics, Computer Science depts.
 **************************************************************

   File: connectivity.h
   Responsable: Weider Chang, Ph.D

 **************************************************************/

#ifndef _H_CONNECTIVITY
#define _H_CONNECTIVITY

#include "oopdb_setup.h"
#include "i_connectivity.h"

#define _H_CONNECTIONINFO

class ConnectionInfo : public IntrConnectionInfo {
};

#include "i_connectivity.h"


class SubEntityConnectivity : public IntrSubEntityConnectivity {
 public:
  SubEntityConnectivity(){};
  SubEntityConnectivity(LineBuffer* line)
    : IntrSubEntityConnectivity(line) {}
};


class ConnectivitySet : public IntrConnectivityMap {
 public:
  ConnectivitySet(){};
  ConnectivitySet(char* filename) : IntrConnectivityMap(filename) {}
};


#endif











